@@ -3,11 +3,8 @@ import torch
 from ._base import Feature
 from .functional import barrier
 from .functional import empty
-from .functional import expiry_time
-from .functional import log_moneyness
 from .functional import max_log_moneyness
 from .functional import max_moneyness
-from .functional import moneyness
 from .functional import prev_hedge
 from .functional import volatility
 from .functional import zeros
@@ -29,9 +26,9 @@ class Moneyness(Feature):
 
     def __getitem__(self, i):
         if self.log:
-            return log_moneyness(i, derivative=self.derivative)
+            return self.derivative.log_moneyness(i).unsqueeze(-1)
         else:
-            return moneyness(i, derivative=self.derivative)
+            return self.derivative.moneyness(i).unsqueeze(-1)
 
 
 class LogMoneyness(Moneyness):
@@ -48,7 +45,7 @@ class ExpiryTime(Feature):
         return "expiry_time"
 
     def __getitem__(self, i):
-        return expiry_time(i, derivative=self.derivative)
+        return self.derivative.time_to_maturity(i).unsqueeze(-1)
 
 
 class Volatility(Feature):
