@@ -1,3 +1,5 @@
+from typing import Optional
+
 import torch
 from torch import Tensor
 
@@ -30,6 +32,7 @@ class BSLookbackOption(BSModuleMixin):
         The `forward` method returns delta of the derivative.
 
         >>> from pfhedge.nn import BSLookbackOption
+        >>>
         >>> m = BSLookbackOption()
         >>> m.inputs()
         ['log_moneyness', 'max_log_moneyness', 'expiry_time', 'volatility']
@@ -68,8 +71,9 @@ class BSLookbackOption(BSModuleMixin):
 
             >>> from pfhedge.instruments import BrownianStock
             >>> from pfhedge.instruments import LookbackOption
-            >>> deriv = LookbackOption(BrownianStock(), strike=1.1)
-            >>> m = BSLookbackOption.from_derivative(deriv)
+            >>>
+            >>> derivative = LookbackOption(BrownianStock(), strike=1.1)
+            >>> m = BSLookbackOption.from_derivative(derivative)
             >>> m
             BSLookbackOption(strike=1.1)
         """
@@ -84,6 +88,57 @@ class BSLookbackOption(BSModuleMixin):
     def inputs(self) -> list:
         return ["log_moneyness", "max_log_moneyness", "expiry_time", "volatility"]
 
+    def price(
+        self,
+        log_moneyness: Tensor,
+        max_log_moneyness: Tensor,
+        expiry_time: Tensor,
+        volatility: Tensor,
+    ) -> Tensor:
+        """Returns price of the derivative.
+
+        Args:
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
+            max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
+            expiry_time (torch.Tensor): Time to expiry of the option.
+            volatility (torch.Tensor): Volatility of the underlying asset.
+
+        Shape:
+            - log_moneyness: :math:`(N, *)`
+            - max_log_moneyness: :math:`(N, *)`
+            - expiry_time: :math:`(N, *)`
+            - volatility: :math:`(N, *)`
+            - output: :math:`(N, *)`
+
+        Returns:
+            Tensor
+        """
+        s, m, t, v = map(
+            torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, volatility)
+        )
+
+        d1 = self.d1(s, t, v)
+        d2 = self.d2(s, t, v)
+        e1 = (s - m + (v ** 2 / 2) * t) / (v * t.sqrt())  # d' in paper
+        e2 = (s - m - (v ** 2 / 2) * t) / (v * t.sqrt())
+
+        # when max moneyness < strike
+        price_0 = self.strike * (
+            s.exp() * self.N.cdf(d1)
+            - self.N.cdf(d2)
+            + s.exp() * v * t.sqrt() * (d1 * self.N.cdf(d1) + self.N.pdf(d1))
+        )
+        # when max moneyness >= strike
+        price_1 = self.strike * (
+            s.exp() * self.N.cdf(e1)
+            - m.exp() * self.N.cdf(e2)
+            + m.exp()
+            - 1
+            + s.exp() * v * t.sqrt() * (e1 * self.N.cdf(e1) + self.N.pdf(e1))
+        )
+
+        return torch.where(m < 0, price_0, price_1)
+
     @torch.enable_grad()
     def delta(
         self,
@@ -92,13 +147,12 @@ class BSLookbackOption(BSModuleMixin):
         expiry_time: Tensor,
         volatility: Tensor,
         create_graph: bool = False,
-        strike: Tensor = None,
+        strike: Optional[Tensor] = None,
     ) -> Tensor:
         """Returns delta of the derivative.
 
         Args:
-            log_moneyness (torch.Tensor): Log moneyness of the prices of the underlying
-                asset.
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
             expiry_time (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
@@ -135,8 +189,7 @@ class BSLookbackOption(BSModuleMixin):
         """Returns gamma of the derivative.
 
         Args:
-            log_moneyness (torch.Tensor): Log moneyness of the prices of the
-                underlying asset.
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
             expiry_time (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor):
@@ -161,57 +214,6 @@ class BSLookbackOption(BSModuleMixin):
             volatility=volatility,
         )
 
-    def price(
-        self,
-        log_moneyness: Tensor,
-        max_log_moneyness: Tensor,
-        expiry_time: Tensor,
-        volatility: Tensor,
-    ) -> Tensor:
-        """Returns price of the derivative.
-
-        Args:
-            log_moneyness (torch.Tensor): Log moneyness of the prices of the underlying asset.
-            max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
-            expiry_time (torch.Tensor): Time to expiry of the option.
-            volatility (torch.Tensor): Volatility of the underlying asset.
-
-        Shape:
-            - log_moneyness: :math:`(N, *)`
-            - max_log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
-            - volatility: :math:`(N, *)`
-            - output: :math:`(N, *)`
-
-        Returns:
-            Tensor
-        """
-        s, m, t, v = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, volatility)
-        )
-
-        d1 = self.d1(s, t, v)
-        d2 = self.d2(s, t, v)
-        e1 = (s - m + (v ** 2 / 2) * t) / (v * torch.sqrt(t))  # d' in paper
-        e2 = (s - m - (v ** 2 / 2) * t) / (v * torch.sqrt(t))
-
-        # when max moneyness < strike
-        price_0 = self.strike * (
-            torch.exp(s) * self.N.cdf(d1)
-            - self.N.cdf(d2)
-            + torch.exp(s) * v * torch.sqrt(t) * (d1 * self.N.cdf(d1) + self.N.pdf(d1))
-        )
-        # when max moneyness >= strike
-        price_1 = self.strike * (
-            torch.exp(s) * self.N.cdf(e1)
-            - torch.exp(m) * self.N.cdf(e2)
-            + torch.exp(m)
-            - 1
-            + torch.exp(s) * v * torch.sqrt(t) * (e1 * self.N.cdf(e1) + self.N.pdf(e1))
-        )
-
-        return torch.where(m < 0, price_0, price_1)
-
     def implied_volatility(
         self,
         log_moneyness: Tensor,
@@ -223,11 +225,11 @@ class BSLookbackOption(BSModuleMixin):
         """Returns implied volatility of the derivative.
 
         Args:
-            log_moneyness (torch.Tensor): Log moneyness of the prices of the underlying asset.
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
             expiry_time (torch.Tensor): Time to expiry of the option.
             price (torch.Tensor): Price of the derivative.
-            precision (float, default=1e-6): Computational precision of the implied volatility.
+            precision (float, default=1e-6): Precision of the implied volatility.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
@@ -242,8 +244,8 @@ class BSLookbackOption(BSModuleMixin):
         s, m, t, p = map(
             torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, price)
         )
-        get_price = lambda volatility: self.price(s, m, t, volatility)
-        return bisect(get_price, p, lower=0.001, upper=1.000, precision=precision)
+        pricer = lambda volatility: self.price(s, m, t, volatility)
+        return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
 
 
 # Assign docstrings so they appear in Sphinx documentation
